# v1.3.34 (2025-02-27)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.33 (2025-02-18)

* **Bug Fix**: Bump go version to 1.22
* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.32 (2025-02-05)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.31 (2025-01-31)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.30 (2025-01-30)

* **Bug Fix**: Do not sign Transfer-Encoding header in Sigv4[a]. Fixes a signer mismatch issue with S3 Accelerate.
* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.29 (2025-01-24)

* **Dependency Update**: Updated to the latest SDK module versions
* **Dependency Update**: Upgrade to smithy-go v1.22.2.

# v1.3.28 (2025-01-15)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.27 (2025-01-09)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.26 (2024-12-19)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.25 (2024-12-02)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.24 (2024-11-18)

* **Dependency Update**: Update to smithy-go v1.22.1.
* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.23 (2024-11-06)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.22 (2024-10-28)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.21 (2024-10-08)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.20 (2024-10-07)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.19 (2024-10-04)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.18 (2024-09-20)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.17 (2024-09-03)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.16 (2024-08-15)

* **Dependency Update**: Bump minimum Go version to 1.21.
* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.15 (2024-07-10.2)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.14 (2024-07-10)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.13 (2024-06-28)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.12 (2024-06-19)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.11 (2024-06-18)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.10 (2024-06-17)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.9 (2024-06-07)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.8 (2024-06-03)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.7 (2024-05-16)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.6 (2024-05-15)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.5 (2024-03-29)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.4 (2024-03-18)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.3 (2024-03-07)

* **Bug Fix**: Remove dependency on go-cmp.
* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.2 (2024-02-23)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.1 (2024-02-21)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.3.0 (2024-02-13)

* **Feature**: Bump minimum Go version to 1.20 per our language support policy.
* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.10 (2024-01-04)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.9 (2023-12-07)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.8 (2023-12-01)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.7 (2023-11-30)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.6 (2023-11-29)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.5 (2023-11-28.2)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.4 (2023-11-20)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.3 (2023-11-15)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.2 (2023-11-09)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.1 (2023-11-01)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.2.0 (2023-10-31)

* **Feature**: **BREAKING CHANGE**: Bump minimum go version to 1.19 per the revised [go version support policy](https://aws.amazon.com/blogs/developer/aws-sdk-for-go-aligns-with-go-release-policy-on-supported-runtimes/).
* **Dependency Update**: Updated to the latest SDK module versions

# v1.1.6 (2023-10-12)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.1.5 (2023-10-06)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.1.4 (2023-08-21)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.1.3 (2023-08-18)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.1.2 (2023-08-17)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.1.1 (2023-08-07)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.1.0 (2023-07-31)

* **Feature**: Adds support for smithy-modeled endpoint resolution. A new rules-based endpoint resolution will be added to the SDK which will supercede and deprecate existing endpoint resolution. Specifically, EndpointResolver will be deprecated while BaseEndpoint and EndpointResolverV2 will take its place. For more information, please see the Endpoints section in our Developer Guide.
* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.28 (2023-07-28)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.27 (2023-07-13)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.26 (2023-06-13)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.25 (2023-04-24)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.24 (2023-04-07)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.23 (2023-03-21)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.22 (2023-03-10)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.21 (2023-02-20)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.20 (2023-02-14)

* No change notes available for this release.

# v1.0.19 (2023-02-03)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.18 (2022-12-15)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.17 (2022-12-02)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.16 (2022-10-24)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.15 (2022-10-21)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.14 (2022-09-20)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.13 (2022-09-14)

* **Bug Fix**: Fixes an issues where an error from an underlying SigV4 credential provider would not be surfaced from the SigV4a credential provider. Contribution by [sakthipriyan-aqfer](https://github.com/sakthipriyan-aqfer).
* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.12 (2022-09-02)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.11 (2022-08-31)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.10 (2022-08-29)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.9 (2022-08-11)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.8 (2022-08-09)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.7 (2022-08-08)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.6 (2022-08-01)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.5 (2022-07-05)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.4 (2022-06-29)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.3 (2022-06-07)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.2 (2022-05-17)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.1 (2022-04-25)

* **Dependency Update**: Updated to the latest SDK module versions

# v1.0.0 (2022-04-07)

* **Release**: New internal v4a signing module location.

